@@ -8,6 +8,9 @@
 #include "bitarray.h"
 #include "logging.h"
 
+#include "protobuf/protobufstreamreader.h"
+#include "rsp/rsp6decoder.h"
+
 #include <QQmlEngine>
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
@@ -76,6 +79,16 @@ QVariant JsApi::ByteArray::toBitArray(const QByteArray &input) const
     return QVariant::fromValue(JsApi::BitArray(input));
 }
 
+QVariant JsApi::ByteArray::toProtobufStreamReader(const QByteArray &input) const
+{
+    return QVariant::fromValue(ProtobufStreamReader(input));
+}
+
+QJSValue JsApi::ByteArray::decodeRsp6Ticket(const QString &text) const
+{
+    return toArrayBuffer(Rsp6Decoder::decode(text.toLatin1()));
+}
+
 QJSValue JsApi::ByteArray::toArrayBuffer(const QByteArray &input) const
 {
     const auto engine = qjsEngine(this);
