@@ -10,6 +10,7 @@
 #include "locationutil.h"
 #include "stringutil.h"
 #include "sortutil.h"
+#include "tickettokencomparator_p.h"
 
 #include <KItinerary/BoatTrip>
 #include <KItinerary/BusTrip>
@@ -30,6 +31,7 @@
 #include <QDebug>
 #include <QMetaObject>
 #include <QMetaProperty>
+#include <QRegularExpression>
 #include <QTimeZone>
 
 #include <cmath>
@@ -53,12 +55,12 @@ static std::vector<CompareFunc> s_mergeCompareFuncs;
 using namespace KItinerary;
 
 /* Checks that @p lhs and @p rhs are non-empty and equal. */
-static bool equalAndPresent(const QString &lhs, const QString &rhs, Qt::CaseSensitivity caseSensitive = Qt::CaseSensitive)
+static bool equalAndPresent(QStringView lhs, QStringView rhs, Qt::CaseSensitivity caseSensitive = Qt::CaseSensitive)
 {
     return !lhs.isEmpty() && (lhs.compare(rhs, caseSensitive) == 0);
 }
 template <typename T>
-static bool equalAndPresent(const T &lhs, const T &rhs)
+static typename std::enable_if<!std::is_same_v<T, QString>, bool>::type equalAndPresent(const T &lhs, const T &rhs)
 {
     return lhs.isValid() && lhs == rhs;
 }
@@ -78,16 +80,6 @@ static bool conflictIfPresent(const Person &lhs, const Person &rhs)
     return !lhs.name().isEmpty() && !rhs.name().isEmpty() && !MergeUtil::isSamePerson(lhs, rhs);
 }
 
-/** Checks that @p lhs and @p rhs have a different prefix is they are both set. */
-static bool prefixConflictIfPresent(const QString &lhs, const QString &rhs, Qt::CaseSensitivity caseSensitive = Qt::CaseSensitive)
-{
-    return !lhs.isEmpty() && !rhs.isEmpty() && !lhs.startsWith(rhs, caseSensitive) && !rhs.startsWith(lhs, caseSensitive);
-}
-static bool prefixConflictIfPresent(const QByteArray &lhs, const QByteArray &rhs)
-{
-    return !lhs.isEmpty() && !rhs.isEmpty() && !lhs.startsWith(rhs) && !rhs.startsWith(lhs);
-}
-
 static bool isSameFlight(const Flight &lhs, const Flight &rhs);
 static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs);
 static bool isSameBusTrip(const BusTrip &lhs, const BusTrip &rhs);
@@ -100,7 +92,6 @@ static bool isSameRentalCar(const RentalCar &lhs, const RentalCar &rhs);
 static bool isSameTaxiTrip(const Taxi &lhs, const Taxi &rhs);
 static bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes);
 static bool isMinimalCancelationFor(const Reservation &res, const Reservation &cancel);
-static bool isSameTicketToken(const QVariant &lhs, const QVariant &rhs);
 
 bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes)
 {
@@ -156,7 +147,7 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         // so we can simply skip this here for flights
         // for other ticket tokens (e.g. Renfe), shorter and longer versions of the same token exist as well
         // so we look for matching prefixes here
-        if (!JsonLd::isA<FlightReservation>(lhs) && !isSameTicketToken(lhsTicket.ticketTokenData(), rhsTicket.ticketTokenData())) {
+        if (!JsonLd::isA<FlightReservation>(lhs) && !TicketTokenComparator::isSame(lhsTicket.ticketTokenData(), rhsTicket.ticketTokenData())) {
             return false;
         }
 
@@ -320,7 +311,7 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
          || conflictIfPresent(lhsTicket.ticketNumber(), rhsTicket.ticketNumber())
          || conflictIfPresent(lhsTicket.name(), rhsTicket.name())
          || conflictIfPresent(lhsTicket.validFrom(), rhsTicket.validFrom())
-         || !isSameTicketToken(lhsTicket.ticketTokenData(), rhsTicket.ticketTokenData())
+         || !TicketTokenComparator::isSame(lhsTicket.ticketTokenData(), rhsTicket.ticketTokenData())
         ) {
             return false;
         }
@@ -336,7 +327,7 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
          || conflictIfPresent(lhsPM.membershipNumber(), rhsPM.membershipNumber())
          || conflictIfPresent(lhsPM.validFrom(), rhsPM.validFrom())
          || conflictIfPresent(lhsPM.validUntil(), rhsPM.validUntil())
-         || !isSameTicketToken(lhsPM.tokenData(), rhsPM.tokenData())
+         || !TicketTokenComparator::isSame(lhsPM.tokenData(), rhsPM.tokenData())
         ) {
             return false;
         }
@@ -415,8 +406,24 @@ static bool isSameLineName(const Iter &lBegin, const Iter &lEnd, const Iter &rBe
 
 static bool isSameLineName(const QString &lhs, const QString &rhs)
 {
-    return isSameLineName(lhs.begin(), lhs.end(), rhs.begin(), rhs.end())
-        || isSameLineName(lhs.rbegin(), lhs.rend(), rhs.rbegin(), rhs.rend());
+    if (isSameLineName(lhs.begin(), lhs.end(), rhs.begin(), rhs.end())
+        || isSameLineName(lhs.rbegin(), lhs.rend(), rhs.rbegin(), rhs.rend()))
+    {
+        return true;
+    }
+
+    // deal with both line and route numbers being specified
+    static QRegularExpression rx(QStringLiteral(R"(^(?<type>[A-Za-z]+) (?<line>\d+)(?: \((?<route>\d{4,})\))?$)"));
+    const auto lhsMatch = rx.match(lhs);
+    const auto rhsMatch = rx.match(rhs);
+    if (!lhsMatch.hasMatch() || !rhsMatch.hasMatch()) {
+        return false;
+    }
+    return equalAndPresent(lhsMatch.capturedView(u"type"), rhsMatch.capturedView(u"type")) && (
+           (equalAndPresent(lhsMatch.capturedView(u"line"), rhsMatch.capturedView(u"line")) && equalAndPresent(lhsMatch.capturedView(u"route"), rhsMatch.capturedView(u"route")))
+        || (equalAndPresent(lhsMatch.capturedView(u"line"), rhsMatch.capturedView(u"route")) && lhsMatch.capturedView(u"route").isEmpty())
+        || (equalAndPresent(lhsMatch.capturedView(u"route"), rhsMatch.capturedView(u"line")) && rhsMatch.capturedView(u"route").isEmpty())
+    );
 }
 
 static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
@@ -471,11 +478,14 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
 
 static bool isSameBusTrip(const BusTrip &lhs, const BusTrip &rhs)
 {
-    if (lhs.busNumber().isEmpty() || rhs.busNumber().isEmpty()) {
+    if (!equalAndPresent(lhs.departureTime(), rhs.departureTime())
+      || conflictIfPresent(lhs.busNumber(), rhs.busNumber())
+      || conflictIfPresent(lhs.arrivalTime(), rhs.arrivalTime())) {
         return false;
     }
 
-    return lhs.busName() == rhs.busName() && lhs.busNumber() == rhs.busNumber() && lhs.departureTime() == rhs.departureTime();
+    return equalAndPresent(lhs.busNumber(), rhs.busNumber()) ||
+        (LocationUtil::isSameLocation(lhs.departureBusStop(), rhs.departureBusStop()) && LocationUtil::isSameLocation(lhs.arrivalBusStop(), rhs.arrivalBusStop()));
 }
 
 static bool isSameBoatTrip(const BoatTrip& lhs, const BoatTrip& rhs)
@@ -559,10 +569,10 @@ static bool isNameEqualish(const QString &lhs, const QString &rhs)
 
 static bool isPartialName(const Person &fullName, const Person &partialName)
 {
-    if (fullName.familyName().isEmpty() || fullName.givenName().isEmpty() || !partialName.givenName().isEmpty()) {
+    if (fullName.familyName().isEmpty() || fullName.givenName().isEmpty() || !fullName.givenName().startsWith(partialName.givenName(), Qt::CaseInsensitive)) {
         return false;
     }
-    return isNameEqualish(fullName.familyName(), partialName.name());
+    return isNameEqualish(fullName.familyName(), partialName.name()) || isNameEqualish(fullName.familyName(), partialName.familyName());
 }
 
 bool MergeUtil::isSamePerson(const Person& lhs, const Person& rhs)
@@ -610,6 +620,30 @@ static bool isSameTaxiTrip(const Taxi &lhs, const Taxi &rhs)
     return lhs.name() == rhs.name();
 }
 
+bool MergeUtil::isSameIncidence(const QVariant &lhs, const QVariant &rhs)
+{
+    if (lhs.userType() != rhs.userType() || !JsonLd::canConvert<Reservation>(lhs) || !JsonLd::canConvert<Reservation>(rhs)) {
+        return false;
+    }
+
+    // special case for LodgingReservation, their time range is in the Reservation object
+    if (JsonLd::isA<LodgingReservation>(lhs)) {
+        if (MergeUtil::isSame(lhs, rhs)) { // incremental updates can have deviating times, that is ok
+            return true;
+        }
+        const auto lhsHotel = lhs.value<LodgingReservation>();
+        const auto rhsHotel = rhs.value<LodgingReservation>();
+        if (lhsHotel.checkinTime().date() != rhsHotel.checkinTime().date() ||
+            lhsHotel.checkoutTime().date() != rhsHotel.checkoutTime().date()) {
+            return false;
+        }
+    }
+
+    const auto lhsTrip = JsonLd::convert<Reservation>(lhs).reservationFor();
+    const auto rhsTrip = JsonLd::convert<Reservation>(rhs).reservationFor();
+    return MergeUtil::isSame(lhsTrip, rhsTrip);
+}
+
 static Airline mergeValue(const Airline &lhs, const Airline &rhs)
 {
     auto a = JsonLdDocument::apply(lhs, rhs).value<Airline>();
@@ -759,26 +793,6 @@ bool isMinimalCancelationFor(const Reservation &res, const Reservation &cancel)
     return SortUtil::startDateTime(res) > cancel.modifiedTime();
 }
 
-bool isSameTicketToken(const QVariant &lhs, const QVariant &rhs)
-{
-    if (lhs.isNull() || rhs.isNull()) {
-        return true;
-    }
-    if (lhs.userType() != rhs.userType()) {
-        return false;
-    }
-
-    if (lhs.userType() == QMetaType::QString) {
-        return !prefixConflictIfPresent(lhs.toString(), rhs.toString(), Qt::CaseInsensitive);
-    }
-    if (lhs.userType() == QMetaType::QByteArray) {
-        return !prefixConflictIfPresent(lhs.toByteArray(), rhs.toByteArray());
-    }
-
-    qCWarning(CompareLog) << "unhandled ticket token type" << lhs << rhs;
-    return false;
-}
-
 static bool isCompatibleLocationChange(const QVariant &lhs, const QVariant &rhs)
 {
     const bool lhsTrainOrBus = JsonLd::isA<TrainReservation>(lhs) || JsonLd::isA<BusReservation>(lhs);
@@ -793,11 +807,24 @@ bool MergeUtil::hasSameDeparture(const QVariant &lhs, const QVariant &rhs)
     }
     const auto lhsRes = JsonLd::convert<Reservation>(lhs);
     const auto rhsRes = JsonLd::convert<Reservation>(rhs);
-    if (!isSameReservation(lhsRes, rhsRes) || SortUtil::startDateTime(lhs) != SortUtil::startDateTime(rhs)) {
+    if (!isSameReservation(lhsRes, rhsRes)) {
         return false;
     }
 
-    return LocationUtil::isSameLocation(LocationUtil::departureLocation(lhs), LocationUtil::departureLocation(rhs), LocationUtil::Exact);
+    if (SortUtil::hasStartTime(lhs) && SortUtil::hasStartTime(rhs)) {
+        if (SortUtil::startDateTime(lhs) != SortUtil::startDateTime(rhs)) {
+            return false;
+        }
+        return LocationUtil::isSameLocation(LocationUtil::departureLocation(lhs), LocationUtil::departureLocation(rhs), LocationUtil::Exact);
+    }
+    if (SortUtil::hasStartTime(lhs) || SortUtil::hasStartTime(rhs)) {
+        if (SortUtil::startDateTime(lhs).date() != SortUtil::startDateTime(rhs).date()) {
+            return false;
+        }
+        return LocationUtil::isSameLocation(LocationUtil::departureLocation(lhs), LocationUtil::departureLocation(rhs), LocationUtil::CityLevel);
+    }
+
+    return false;
 }
 
 bool MergeUtil::hasSameArrival(const QVariant &lhs, const QVariant &rhs)
@@ -807,11 +834,25 @@ bool MergeUtil::hasSameArrival(const QVariant &lhs, const QVariant &rhs)
     }
     const auto lhsRes = JsonLd::convert<Reservation>(lhs);
     const auto rhsRes = JsonLd::convert<Reservation>(rhs);
-    if (!isSameReservation(lhsRes, rhsRes) || SortUtil::endDateTime(lhs) != SortUtil::endDateTime(rhs)) {
+    if (!isSameReservation(lhsRes, rhsRes)) {
         return false;
     }
 
-    return LocationUtil::isSameLocation(LocationUtil::arrivalLocation(lhs), LocationUtil::arrivalLocation(rhs), LocationUtil::Exact);
+    if (SortUtil::hasEndTime(lhs) && SortUtil::hasEndTime(rhs)) {
+        if (SortUtil::endDateTime(lhs) != SortUtil::endDateTime(rhs)) {
+            return false;
+        }
+        return LocationUtil::isSameLocation(LocationUtil::arrivalLocation(lhs), LocationUtil::arrivalLocation(rhs), LocationUtil::Exact);
+    }
+
+    if (SortUtil::hasEndTime(lhs) || SortUtil::hasEndTime(rhs)) {
+        if (SortUtil::endDateTime(lhs).date() != SortUtil::endDateTime(rhs).date()) {
+            return false;
+        }
+        return LocationUtil::isSameLocation(LocationUtil::arrivalLocation(lhs), LocationUtil::arrivalLocation(rhs), LocationUtil::CityLevel);
+    }
+
+    return false;
 }
 
 void MergeUtil::registerComparator(int metaTypeId, std::function<bool (const QVariant&, const QVariant&)> &&func)
